@@ -1,5 +1,5 @@
 
-/* GnomeMeeting -- A Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -68,7 +68,8 @@ GMSignalFilter::GMSignalFilter ()
 }
 
 
-void GMSignalFilter::ReceivedPacket (RTP_DataFrame & frame, INT)
+void GMSignalFilter::ReceivedPacket (RTP_DataFrame & frame,
+				     INT unused)
 {
   // Silent
   if (frame.GetPayloadSize() == 0)
@@ -82,7 +83,8 @@ void GMSignalFilter::ReceivedPacket (RTP_DataFrame & frame, INT)
 }
 
 
-void GMSignalFilter::SentPacket (RTP_DataFrame & frame, INT)
+void GMSignalFilter::SentPacket (RTP_DataFrame & frame,
+				 INT unused)
 {
   // Silent
   if (frame.GetPayloadSize() == 0)
@@ -101,6 +103,7 @@ GMPCSSEndpoint::GMPCSSEndpoint (GMManager & ep)
 {
   NoAnswerTimer.SetNotifier (PCREATE_NOTIFIER (OnNoAnswerTimeout));
   CallPendingTimer.SetNotifier (PCREATE_NOTIFIER (OnCallPending));
+  OutgoingCallTimer.SetNotifier (PCREATE_NOTIFIER (OnOutgoingCall));
 
   signal_filter = new GMSignalFilter ();
 }
@@ -112,6 +115,24 @@ GMPCSSEndpoint::~GMPCSSEndpoint ()
 }
 
 
+BOOL 
+GMPCSSEndpoint::MakeConnection (OpalCall & call, 
+                                const PString & party,  
+                                void * userData)
+{
+  BOOL result = FALSE;
+  
+  OutgoingCallTimer.RunContinuous (PTimeInterval (5));
+  
+  result = OpalPCSSEndPoint::MakeConnection (call, party, userData);
+
+  if (!result)
+    OutgoingCallTimer.Stop ();
+
+  return result;
+}
+
+
 void GMPCSSEndpoint::AcceptCurrentIncomingCall ()
 {
   if (!incomingConnectionToken.IsEmpty ()) {
@@ -129,6 +150,9 @@ void GMPCSSEndpoint::OnShowIncoming (const OpalPCSSConnection & connection)
   GtkWidget *statusicon = NULL;
   guint interval = 1000;
 
+  if (endpoint.GetCallingState() != GMManager::Called)
+    return;
+
   statusicon = GnomeMeeting::Process ()->GetStatusicon ();
 
   /* Check the config keys */
@@ -147,14 +171,13 @@ void GMPCSSEndpoint::OnShowIncoming (const OpalPCSSConnection & connection)
     AcceptCurrentIncomingCall ();
     return;
   }
-  
+
   /* The timers */
   NoAnswerTimer.SetInterval (0, PMAX (no_answer_timeout, 10));
   CallPendingTimer.RunContinuous (interval);
   gnomemeeting_threads_enter ();
   gm_statusicon_ring (statusicon, interval);
   gnomemeeting_threads_leave ();
-
 }
 
 
@@ -197,6 +220,9 @@ GMPCSSEndpoint::CreateSoundChannel (const OpalPCSSConnection & connection,
   /* Stop the OnNoAnswerTimers */
   NoAnswerTimer.Stop ();
   CallPendingTimer.Stop ();
+  OutgoingCallTimer.Stop ();
+
+  /* Update the GUI */
   gnomemeeting_threads_enter ();
   gm_statusicon_stop_ringing (statusicon);
   gnomemeeting_threads_leave ();
@@ -279,6 +305,8 @@ GMPCSSEndpoint::OnEstablished (OpalConnection &connection)
 
   NoAnswerTimer.Stop ();
   CallPendingTimer.Stop ();
+  OutgoingCallTimer.Stop ();
+
   gnomemeeting_threads_enter ();
   gm_statusicon_stop_ringing (statusicon);
   gnomemeeting_threads_leave ();
@@ -298,6 +326,7 @@ GMPCSSEndpoint::OnReleased (OpalConnection &connection)
 
   NoAnswerTimer.Stop ();
   CallPendingTimer.Stop ();
+  OutgoingCallTimer.Stop ();
 
   gnomemeeting_threads_enter ();
   gm_statusicon_stop_ringing (statusicon);
@@ -311,7 +340,7 @@ GMPCSSEndpoint::OnReleased (OpalConnection &connection)
 
 
 PString 
-GMPCSSEndpoint::OnGetDestination (const OpalPCSSConnection &)
+GMPCSSEndpoint::OnGetDestination (const OpalPCSSConnection &connection)
 {
   return PString ();
 }
@@ -431,6 +460,17 @@ GMPCSSEndpoint::OnNoAnswerTimeout (PTimer &,
 }
 
 
+void
+GMPCSSEndpoint::OnOutgoingCall (PTimer &,
+                                INT) 
+{
+  PlaySoundEvent ("ring_tone_sound");
+
+  if (OutgoingCallTimer.IsRunning ())
+    OutgoingCallTimer.RunContinuous (PTimeInterval (0, 3));
+}
+
+
 void
 GMPCSSEndpoint::OnCallPending (PTimer &,
 			       INT) 
