@@ -93,7 +93,7 @@ GMSIPEndpoint::Init ()
   SetInviteTimeout (PTimeInterval (0, 6));
   SetNonInviteTimeout (PTimeInterval (0, 6));
   SetNATBindingTimeout (PTimeInterval (0, binding_timeout));
-  SetRetryTimeouts (250, 10000);
+  SetRetryTimeouts (500, 4000);
   SetMaxRetries (8);
 
 
@@ -232,11 +232,6 @@ GMSIPEndpoint::OnRegistered (const PString & domain,
 				     endpoint.GetRegisteredAccounts());
   gnomemeeting_threads_leave ();
 
-
-  /* MWI Subscribe */
-  if (wasRegistering && !IsSubscribed (domain, username))
-    MWISubscribe (domain, username); 
-
   /* Signal the SIPEndpoint */
   SIPEndPoint::OnRegistered (domain, username, wasRegistering);
 
@@ -364,8 +359,11 @@ GMSIPEndpoint::OnIncomingConnection (OpalConnection &connection)
   call = endpoint.FindCallWithLock (endpoint.GetCurrentCallToken());
   if (call)
     con = endpoint.GetConnection (call, TRUE);
-  if ((con && con->GetIdentifier () == connection.GetIdentifier()) 
-      || (icm == DO_NOT_DISTURB))
+  if ((con && con->GetIdentifier () == connection.GetIdentifier())) {
+    return TRUE;
+  }
+  
+  if (icm == DO_NOT_DISTURB)
     reason = 1;
   else if (forward_host && always_forward)
     reason = 2; // Forward
@@ -541,3 +539,23 @@ GMSIPEndpoint::GetRegisteredAccounts ()
 {
   return SIPEndPoint::GetRegistrationsCount ();
 }
+
+
+SIPURL
+GMSIPEndpoint::GetDefaultRegisteredPartyName ()
+{
+  GmAccount *account = NULL;
+  
+  PString url;
+
+  account = gnomemeeting_get_default_account ("SIP");
+  if (account) {
+
+    if (PString(account->username).Find("@") == P_MAX_INDEX)
+      url = PString (account->username) + "@" + PString (account->host);
+
+    return url;
+  }
+  
+  return SIPEndPoint::GetDefaultRegisteredPartyName (); 
+}
