@@ -90,14 +90,14 @@ typedef struct GmAccountsWindow_ {
  * BEHAVIOR     : Returns a GmAccount from its string representation.
  * PRE          : /
  */
-static GmAccount *gm_aw_from_string_to_account (gchar *);
+static GmAccount *gm_aw_from_string_to_account (gchar *str);
 
 
 /* DESCRIPTION  : /
  * BEHAVIOR     : Returns a string representing a GmAccount.
  * PRE          : /
  */
-static gchar *gm_aw_from_account_to_string (GmAccount *);
+static gchar *gm_aw_from_account_to_string (GmAccount *account);
 
 
 /* GUI Functions */
@@ -106,7 +106,7 @@ static gchar *gm_aw_from_account_to_string (GmAccount *);
  * BEHAVIOR     : Frees a GmAccountsWindow and its content.
  * PRE          : A non-NULL pointer to a GmAccountsWindow structure.
  */
-static void gm_aw_destroy (gpointer);
+static void gm_aw_destroy (gpointer aw);
 
 
 /* DESCRIPTION  : /
@@ -115,7 +115,7 @@ static void gm_aw_destroy (gpointer);
  * PRE          : The given GtkWidget pointer must be a preferences window 
  * 		  GMObject.
  */
-static GmAccountsWindow *gm_aw_get_aw (GtkWidget *);
+static GmAccountsWindow *gm_aw_get_aw (GtkWidget *account_window);
 
 
 /* DESCRIPTION  : /
@@ -183,7 +183,7 @@ static void account_toggled_cb (GtkCellRendererToggle *cell,
  * 		   it with correct data.
  * PRE          :  /
  */
-static void add_account_cb (GtkWidget *button, 
+static void add_account_cb (GtkWidget *button,
 			    gpointer data);
 
 
@@ -193,8 +193,8 @@ static void add_account_cb (GtkWidget *button,
  * 		   it with correct data.
  * PRE          :  The accounts window GMObject.
  */
-static void edit_account1_cb (GtkWidget *button, 
-			     gpointer data);
+static void edit_account1_cb (GtkWidget *button,
+			      gpointer data);
 
 
 /* DESCRIPTION  :  This callback is called when the user chooses to edit
@@ -211,9 +211,10 @@ static void edit_account2_cb (GtkTreeView *tree_view,
 /* DESCRIPTION  :  This callback is called when the user chooses to set
  * 		   an account as default.
  * BEHAVIOR     :  It sets it as default, only one default at a time.
+ *                 It also updates the various endpoints with the new default.
  * PRE          :  /
  */
-static void set_account_as_default_cb (GtkWidget *button, 
+static void set_account_as_default_cb (GtkWidget *button,
 				       gpointer data);
 
 
@@ -223,7 +224,7 @@ static void set_account_as_default_cb (GtkWidget *button,
  * 		   it.
  * PRE          :  /
  */
-static void delete_account_cb (GtkWidget *button, 
+static void delete_account_cb (GtkWidget *button,
 			       gpointer data);
 
 
@@ -407,7 +408,7 @@ gm_aw_edit_account_dialog_run (GtkWidget *accounts_window,
     gtk_dialog_new_with_buttons (_("Edit the Account Information"), 
 				 GTK_WINDOW (NULL),
 				 GTK_DIALOG_MODAL,
-				 GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+				 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				 GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 				 NULL);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog),
@@ -656,7 +657,8 @@ gm_aw_edit_account_dialog_run (GtkWidget *accounts_window,
       }
       break;
 
-    case GTK_RESPONSE_REJECT:
+    case GTK_RESPONSE_DELETE_EVENT:
+    case GTK_RESPONSE_CANCEL:
       valid = TRUE;
       break;
     }
@@ -885,13 +887,24 @@ static void
 set_account_as_default_cb (GtkWidget *button, 
 			   gpointer data)
 {
+  GMManager *ep = NULL;
+
   GmAccount *account = NULL;
+
   GtkWidget *accounts_window = NULL;
 
   accounts_window = GnomeMeeting::Process ()->GetAccountsWindow (); 
+  ep = GnomeMeeting::Process ()->GetManager ();
 
+  /* Update the config */
   account = gm_aw_get_selected_account (accounts_window);
   gnomemeeting_account_set_default (account, TRUE);
+
+  /* Update the account */
+  gdk_threads_leave ();
+  ep->SetUserNameAndAlias ();
+  gdk_threads_enter ();
+  
   gm_account_delete (account);
 }
 
@@ -1441,7 +1454,7 @@ gm_accounts_window_new ()
 
   /* The window */
   window = gtk_dialog_new ();
-  gtk_dialog_add_button (GTK_DIALOG (window), GTK_STOCK_CLOSE, 0);
+  gtk_dialog_add_button (GTK_DIALOG (window), GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL);
 
   g_object_set_data_full (G_OBJECT (window), "window_name",
 			  g_strdup ("accounts_window"), g_free);
@@ -1621,8 +1634,6 @@ gm_accounts_window_update_account_state (GtkWidget *accounts_window,
 					 const gchar *status,
 					 const gchar *voicemails)
 {
-  OpalTransportAddress addr;
-
   GtkTreeModel *model = NULL;
 
   GtkTreeIter iter;
@@ -1654,11 +1665,7 @@ gm_accounts_window_update_account_state (GtkWidget *accounts_window,
 			  COLUMN_ACCOUNT_USERNAME, &username,
 			  -1);
 
-      if (host)
-	addr = OpalTransportAddress (host);
-
-      if (((host && hostname && !strcmp (host, hostname)
-	    || !strcmp (addr.GetHostName (), hostname))
+      if ((host && hostname && !strcmp (SIPURL(host).GetHostName (), hostname)
 	   || (realm && hostname && !strcmp (realm, hostname)))
 	  && (username && user && (!strcmp (SIPURL(username).GetUserName(), user) || !strcmp (username, user)))) {
 
